@@ -19,7 +19,12 @@ try:
 except ImportError:
     Session = None
 else:
-    Session = scoped_session(sessionmaker(autoflush=False, transactional=True), scopefunc=lambda:__name__)
+    import sqlalchemy
+    sa_major = float(sqlalchemy.__version__[:3]) # i.e. 0.4 or 0.5
+    if sa_major < 0.5:
+        Session = scoped_session(sessionmaker(autoflush=False, transactional=True), scopefunc=lambda:__name__)
+    else:
+        Session = scoped_session(sessionmaker(autoflush=False, autocommit=False), scopefunc=lambda:__name__)
 
 def negotiated_medium(obj, dataset):
     if is_table(obj):
@@ -128,10 +133,9 @@ class SQLAlchemyFixture(DBLoadableFixture):
         
         if self.session is None:
             if self.connection:
-                self.Session.configure(bind=self.connection)
+                self.session = self.Session(bind=self.connection)
             else:
-                self.Session.configure(bind=None)
-            self.session = self.Session()
+                self.session = self.Session(bind=None)
             
         DBLoadableFixture.begin(self, unloading=unloading)
     
